# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#
#

from tb_rest_client32.api.api_ce import *
from tb_rest_client32.api.api_pe import *
from tb_rest_client32.models.models_ce import *
from tb_rest_client32.models.models_pe import *
from tb_rest_client32.rest_client_base import *

logger = getLogger(__name__)


class RestClientPE(RestClientBase):
    def __init__(self, base_url):
        super().__init__(base_url)

    def login(self, username, password):
        super(RestClientPE, self).login(username=username, password=password)
        self.__load_controllers()

    def get_assets_by_entity_group_id(self, entity_group_id: EntityGroupId, page_size=100, page=0, **kwargs):
        return self.asset_controller.get_assets_by_entity_group_id_using_get(entity_group_id.id, str(page_size), str(page), **kwargs)

    def get_user_assets(self, page_size=100, page=0, **kwargs):
        return self.asset_controller.get_user_assets_using_get(str(page_size), str(page), **kwargs)

    def get_all_customer_users(self, page_size=100, page=0, **kwargs):
        return self.user_controller.get_all_customer_users_using_get(str(page_size), str(page), **kwargs)

    def get_user_users(self, page_size=100, page=0, **kwargs):
        return self.user_controller.get_user_users_using_get(str(page_size), str(page), **kwargs)

    def get_users_by_entity_group_id(self, entity_group_id: EntityGroupId, page_size=100, page=0, **kwargs):
        return self.user_controller.get_users_by_entity_group_id_using_get(entity_group_id.id, str(page_size), str(page), **kwargs)

    def get_users_by_ids(self, user_ids, **kwargs):
        return self.user_controller.get_users_by_ids_using_get(user_ids, **kwargs)

    def get_devices_by_entity_group_id(self, entity_group_id: EntityGroupId, page_size=100, page=0, **kwargs):
        return self.device_controller.get_devices_by_entity_group_id_using_get(entity_group_id.id, str(page_size), str(page), **kwargs)

    def get_user_devices(self, page_size=100, page=0, **kwargs):
        return self.device_controller.get_user_devices_using_get(str(page_size), str(page), **kwargs)

    """ EntityGroupController endpoints """

    def add_entities_to_entity_group(self, entity_group_id: EntityGroupId, str_entity_ids, **kwargs):
        return self.entity_group_controller.add_entities_to_entity_group_using_post(entity_group_id.id, str_entity_ids, **kwargs)

    def delete_entity_group(self, entity_group_id: EntityGroupId, **kwargs):
        return self.entity_group_controller.delete_entity_group_using_delete(entity_group_id.id, **kwargs)

    def get_entities(self, entity_group_id: EntityGroupId, page_size=100, page=0, **kwargs):
        return self.entity_group_controller.get_entities_using_get(entity_group_id.id, str(page_size), str(page), **kwargs)

    def get_entity_group_all_by_owner_and_type(self, owner_id: EntityId, group_type, **kwargs):
        return self.entity_group_controller.get_entity_group_all_by_owner_and_type_using_get(owner_id.entity_type, owner_id.id, group_type, **kwargs)

    def get_entity_group_by_id(self, entity_group_id: EntityGroupId, **kwargs):
        return self.entity_group_controller.get_entity_group_by_id_using_get(entity_group_id.id, **kwargs)

    def get_entity_group_by_owner_and_name_and_type(self, owner_id: EntityId, group_type, group_name, **kwargs):
        return self.entity_group_controller.get_entity_group_by_owner_and_name_and_type_using_get(owner_id.entity_type, owner_id.id, group_type, group_name, **kwargs)

    def get_entity_groups_by_ids(self, entity_group_ids, **kwargs):
        return self.entity_group_controller.get_entity_groups_by_ids_using_get(entity_group_ids, **kwargs)

    def get_entity_groups_by_owner_and_type(self, owner_id: EntityId, group_type, **kwargs):
        return self.entity_group_controller.get_entity_groups_by_owner_and_type_using_get(owner_id.entity_type, owner_id.id, group_type, **kwargs)

    def get_entity_groups_by_type(self, group_type, **kwargs):
        return self.entity_group_controller.get_entity_groups_by_type_using_get(group_type, **kwargs)

    def get_entity_groups_for_entity(self, entity_id: EntityId, **kwargs):
        return self.entity_group_controller.get_entity_groups_for_entity_using_get(entity_id.entity_type, entity_id.id, **kwargs)

    def get_group_entity(self, entity_group_id: EntityGroupId, entity_id: EntityId, **kwargs):
        return self.entity_group_controller.get_group_entity_using_get(entity_group_id.id, entity_id.id, **kwargs)

    def get_owners(self, page_size=100, page=0, **kwargs):
        return self.entity_group_controller.get_owners_using_get(str(page_size), str(page), **kwargs)

    def make_entity_group_private(self, entity_group_id: EntityGroupId, **kwargs):
        return self.entity_group_controller.make_entity_group_private_using_post(entity_group_id.id, **kwargs)

    def make_entity_group_public(self, entity_group_id: EntityGroupId, **kwargs):
        return self.entity_group_controller.make_entity_group_public_using_post(entity_group_id.id, **kwargs)

    def remove_entities_from_entity_group(self, entity_group_id: EntityGroupId, str_entity_ids, **kwargs):
        return self.entity_group_controller.remove_entities_from_entity_group_using_post(entity_group_id.id, str_entity_ids, **kwargs)

    def save_entity_group(self, entity_group, **kwargs):
        return self.entity_group_controller.save_entity_group_using_post(entity_group, **kwargs)

    def share_entity_group_to_child_owner_user_group(self, entity_group_id: EntityGroupId, user_group_id, role_id: RoleId, **kwargs):
        return self.entity_group_controller.share_entity_group_to_child_owner_user_group_using_post(entity_group_id.id, user_group_id.id, role_id.id, **kwargs)

    def share_entity_group(self, entity_group_id: EntityGroupId, share_group_request, **kwargs):
        return self.entity_group_controller.share_entity_group_using_post(entity_group_id.id, share_group_request, **kwargs)

    ##################################

    """ HttpIntegrationController endpoints """

    def check_status(self, routing_key, request_params, request_headers, **kwargs):
        return self.http_integration_controller.check_status_using_get(routing_key, request_params, request_headers, **kwargs)

    def process_request3(self, routing_key, suffix, request_params, request_headers, **kwargs):
        return self.http_integration_controller.process_request_using_post3(routing_key, suffix, request_params, request_headers, **kwargs)

    def process_request4(self, routing_key, suffix, msg, request_headers, **kwargs):
        return self.http_integration_controller.process_request_using_post4(routing_key, suffix, msg, request_headers, **kwargs)

    """ CustomTranslationController endpoints """

    def get_current_custom_translation(self, **kwargs):
        return self.custom_translation_controller.get_current_custom_translation_using_get(**kwargs)

    def get_custom_translation(self, **kwargs):
        return self.custom_translation_controller.get_custom_translation_using_get(**kwargs)

    def save_custom_translation(self, custom_translation, **kwargs):
        return self.custom_translation_controller.save_custom_translation_using_post(custom_translation, **kwargs)

    """ BlobEntityController endpoints """

    def delete_blob_entity(self, blob_entity_id: BlobEntityId, **kwargs):
        return self.blob_entity_controller.delete_blob_entity_using_delete(blob_entity_id.id, **kwargs)

    def download_blob_entity(self, blob_entity_id: BlobEntityId, **kwargs):
        return self.blob_entity_controller.download_blob_entity_using_get(blob_entity_id.id, **kwargs)

    def get_blob_entities_by_ids(self, blob_entity_ids, **kwargs):
        return self.blob_entity_controller.get_blob_entities_by_ids_using_get(blob_entity_ids, **kwargs)

    def get_blob_entities(self, page_size=100, page=0, **kwargs):
        return self.blob_entity_controller.get_blob_entities_using_get(str(page_size), str(page), **kwargs)

    def get_blob_entity_info_by_id(self, blob_entity_id: BlobEntityId, **kwargs):
        return self.blob_entity_controller.get_blob_entity_info_by_id_using_get(blob_entity_id.id, **kwargs)

    """ TMobileIotCdpIntegrationController endpoints """

    def process_check_using_delete(self, routing_key, **kwargs):
        return self.tmobile_iot_cdp_integration_controller.process_check_using_delete(routing_key, **kwargs)

    def process_check_using_get(self, routing_key, **kwargs):
        return self.tmobile_iot_cdp_integration_controller.process_check_using_get(routing_key, **kwargs)

    def process_check_using_head(self, routing_key, **kwargs):
        return self.tmobile_iot_cdp_integration_controller.process_check_using_head(routing_key, **kwargs)

    def process_check_using_options(self, routing_key, **kwargs):
        return self.tmobile_iot_cdp_integration_controller.process_check_using_options(routing_key, **kwargs)

    def process_check_using_patch(self, routing_key, **kwargs):
        return self.tmobile_iot_cdp_integration_controller.process_check_using_patch(routing_key, **kwargs)

    def process_check(self, routing_key, **kwargs):
        return self.tmobile_iot_cdp_integration_controller.process_check_using_post(routing_key, **kwargs)

    def process_check_using_put(self, routing_key, **kwargs):
        return self.tmobile_iot_cdp_integration_controller.process_check_using_put(routing_key, **kwargs)

    """ UserPermissionsController endpoints """

    def get_allowed_permissions(self, **kwargs):
        return self.user_permissions_controller.get_allowed_permissions_using_get(**kwargs)

    """ OceanConnectIntegrationController endpoints """

    def process_request_using_delete(self, routing_key, msg, request_headers, **kwargs):
        return self.ocean_connect_integration_controller.process_request_using_delete(routing_key, msg, request_headers, **kwargs)

    def process_request_using_get(self, routing_key, msg, request_headers, **kwargs):
        return self.ocean_connect_integration_controller.process_request_using_get(routing_key, msg, request_headers, **kwargs)

    def process_request_using_head(self, routing_key, msg, request_headers, **kwargs):
        return self.ocean_connect_integration_controller.process_request_using_head(routing_key, msg, request_headers, **kwargs)

    def process_request_using_options(self, routing_key, msg, request_headers, **kwargs):
        return self.ocean_connect_integration_controller.process_request_using_options(routing_key, msg, request_headers, **kwargs)

    def process_request_using_patch(self, routing_key, msg, request_headers, **kwargs):
        return self.ocean_connect_integration_controller.process_request_using_patch(routing_key, msg, request_headers, **kwargs)

    def process_request6(self, routing_key, msg, request_headers, **kwargs):
        return self.ocean_connect_integration_controller.process_request_using_post6(routing_key, msg, request_headers, **kwargs)

    def process_request_using_put(self, routing_key, msg, request_headers, **kwargs):
        return self.ocean_connect_integration_controller.process_request_using_put(routing_key, msg, request_headers, **kwargs)

    """ SchedulerEventController endpoints """

    def delete_scheduler_event(self, scheduler_event_id: SchedulerEventId, **kwargs):
        return self.scheduler_event_controller.delete_scheduler_event_using_delete(scheduler_event_id.id, **kwargs)

    def get_scheduler_event_by_id(self, scheduler_event_id: SchedulerEventId, **kwargs):
        return self.scheduler_event_controller.get_scheduler_event_by_id_using_get(scheduler_event_id.id, **kwargs)

    def get_scheduler_event_info_by_id(self, scheduler_event_id: SchedulerEventId, **kwargs):
        return self.scheduler_event_controller.get_scheduler_event_info_by_id_using_get(scheduler_event_id.id, **kwargs)

    def get_scheduler_events_by_ids(self, scheduler_event_ids, **kwargs):
        return self.scheduler_event_controller.get_scheduler_events_by_ids_using_get(scheduler_event_ids, **kwargs)

    def get_scheduler_events(self, **kwargs):
        return self.scheduler_event_controller.get_scheduler_events_using_get(**kwargs)

    def save_scheduler_event(self, scheduler_event, **kwargs):
        return self.scheduler_event_controller.save_scheduler_event_using_post(scheduler_event, **kwargs)

    """ SignUpController endpoints """

    def accept_privacy_policy(self, **kwargs):
        return self.sign_up_controller.accept_privacy_policy_using_post(**kwargs)

    def activate_email(self, email_code, **kwargs):
        return self.sign_up_controller.activate_email_using_get(email_code, **kwargs)

    def activate_user_by_email_code(self, email_code, **kwargs):
        return self.sign_up_controller.activate_user_by_email_code_using_post(email_code, **kwargs)

    def privacy_policy_accepted(self, **kwargs):
        return self.sign_up_controller.privacy_policy_accepted_using_get(**kwargs)

    def resend_email_activation(self, email, **kwargs):
        return self.sign_up_controller.resend_email_activation_using_post(email, **kwargs)

    def sign_up(self, sign_up_request, **kwargs):
        return self.sign_up_controller.sign_up_using_post(sign_up_request, **kwargs)

    """ SelfRegistrationController endpoints """

    def get_privacy_policy(self, **kwargs):
        return self.self_registration_controller.get_privacy_policy_using_get(**kwargs)

    def get_self_registration_params(self, **kwargs):
        return self.self_registration_controller.get_self_registration_params_using_get(**kwargs)

    def get_sign_up_self_registration_params(self, **kwargs):
        return self.self_registration_controller.get_sign_up_self_registration_params_using_get(**kwargs)

    def save_self_registration_params(self, self_registration_params, **kwargs):
        return self.self_registration_controller.save_self_registration_params_using_post(self_registration_params, **kwargs)

    """ WhiteLabelingController endpoints """

    def get_app_theme_css(self, palette_settings, **kwargs):
        return self.white_labeling_controller.get_app_theme_css_using_post(palette_settings, **kwargs)

    def get_current_login_white_label_params(self, **kwargs):
        return self.white_labeling_controller.get_current_login_white_label_params_using_get(**kwargs)

    def get_current_white_label_params(self, **kwargs):
        return self.white_labeling_controller.get_current_white_label_params_using_get(**kwargs)

    def get_login_theme_css(self, palette_settings, **kwargs):
        return self.white_labeling_controller.get_login_theme_css_using_post(palette_settings, **kwargs)

    def get_login_white_label_params(self, **kwargs):
        return self.white_labeling_controller.get_login_white_label_params_using_get(**kwargs)

    def get_white_label_params(self, **kwargs):
        return self.white_labeling_controller.get_white_label_params_using_get(**kwargs)

    def is_customer_white_labeling_allowed(self, **kwargs):
        return self.white_labeling_controller.is_customer_white_labeling_allowed_using_get(**kwargs)

    def is_white_labeling_allowed(self, **kwargs):
        return self.white_labeling_controller.is_white_labeling_allowed_using_get(**kwargs)

    def preview_white_label_params(self, white_labeling_params, **kwargs):
        return self.white_labeling_controller.preview_white_label_params_using_post(white_labeling_params, **kwargs)

    def save_login_white_label_params(self, login_white_labeling_params, **kwargs):
        return self.white_labeling_controller.save_login_white_label_params_using_post(login_white_labeling_params, **kwargs)

    def save_white_label_params(self, white_labeling_params, **kwargs):
        return self.white_labeling_controller.save_white_label_params_using_post(white_labeling_params, **kwargs)

    """ RoleController endpoints """

    def delete_role(self, role_id: RoleId, **kwargs):
        return self.role_controller.delete_role_using_delete(role_id.id, **kwargs)

    def get_role_by_id(self, role_id: RoleId, **kwargs):
        return self.role_controller.get_role_by_id_using_get(role_id.id, **kwargs)

    def get_roles_by_ids(self, role_ids, **kwargs):
        return self.role_controller.get_roles_by_ids_using_get(role_ids, **kwargs)

    def get_roles(self, page_size=100, page=0, **kwargs):
        return self.role_controller.get_roles_using_get(str(page_size), str(page), **kwargs)

    def save_role(self, role, **kwargs):
        return self.role_controller.save_role_using_post(role, **kwargs)

    """ SigFoxIntegrationController endpoints """

    def process_request_using_delete1(self, routing_key, msg, request_headers, **kwargs):
        return self.sigfox_integration_controller.process_request_using_delete1(routing_key, msg, request_headers, **kwargs)

    def process_request_using_get1(self, routing_key, msg, request_headers, **kwargs):
        return self.sigfox_integration_controller.process_request_using_get1(routing_key, msg, request_headers, **kwargs)

    def process_request_using_head1(self, routing_key, msg, request_headers, **kwargs):
        return self.sigfox_integration_controller.process_request_using_head1(routing_key, msg, request_headers, **kwargs)

    def process_request_using_options1(self, routing_key, msg, request_headers, **kwargs):
        return self.sigfox_integration_controller.process_request_using_options1(routing_key, msg, request_headers, **kwargs)

    def process_request_using_patch1(self, routing_key, msg, request_headers, **kwargs):
        return self.sigfox_integration_controller.process_request_using_patch1(routing_key, msg, request_headers, **kwargs)

    def process_request7(self, routing_key, msg, request_headers, **kwargs):
        return self.sigfox_integration_controller.process_request_using_post7(routing_key, msg, request_headers, **kwargs)

    def process_request_using_put1(self, routing_key, msg, request_headers, **kwargs):
        return self.sigfox_integration_controller.process_request_using_put1(routing_key, msg, request_headers, **kwargs)

    """ IntegrationController endpoints """

    def check_integration_connection(self, integration, **kwargs):
        return self.integration_controller.check_integration_connection_using_post(integration, **kwargs)

    def delete_integration(self, integration_id: IntegrationId, **kwargs):
        return self.integration_controller.delete_integration_using_delete(integration_id.id, **kwargs)

    def get_integration_by_id(self, integration_id: IntegrationId, **kwargs):
        return self.integration_controller.get_integration_by_id_using_get(integration_id.id, **kwargs)

    def get_integration_by_routing_key(self, routing_key, **kwargs):
        return self.integration_controller.get_integration_by_routing_key_using_get(routing_key, **kwargs)

    def get_integrations_by_ids(self, integration_ids, **kwargs):
        return self.integration_controller.get_integrations_by_ids_using_get(integration_ids, **kwargs)

    def get_integrations(self, page_size=100, page=0, **kwargs):
        return self.integration_controller.get_integrations_using_get(str(page_size), str(page), **kwargs)

    def save_integration(self, integration, **kwargs):
        return self.integration_controller.save_integration_using_post(integration, **kwargs)

    """ OwnerController endpoints """

    def change_owner_to_customer(self, owner_id, entity_id: EntityId, **kwargs):
        return self.owner_controller.change_owner_to_customer_using_post(owner_id.id, entity_id.entity_type, entity_id.id, **kwargs)

    def change_owner_to_tenant(self, owner_id, entity_id: EntityId, **kwargs):
        return self.owner_controller.change_owner_to_tenant_using_post(owner_id, entity_id.entity_type, entity_id.id, **kwargs)

    """ GroupPermissionController endpoints """

    def delete_group_permission(self, group_permission_id: GroupPermissionId, **kwargs):
        return self.group_permission_controller.delete_group_permission_using_delete(group_permission_id.id, **kwargs)

    def get_entity_group_permissions(self, entity_group_id: EntityGroupId, **kwargs):
        return self.group_permission_controller.get_entity_group_permissions_using_get(entity_group_id.id, **kwargs)

    def get_group_permission_by_id(self, group_permission_id: GroupPermissionId, **kwargs):
        return self.group_permission_controller.get_group_permission_by_id_using_get(group_permission_id.id, **kwargs)

    def get_group_permission_info_by_id(self, group_permission_id: GroupPermissionId, is_user_group, **kwargs):
        return self.group_permission_controller.get_group_permission_info_by_id_using_get(group_permission_id.id, is_user_group, **kwargs)

    def get_user_group_permissions(self, user_group_id, **kwargs):
        return self.group_permission_controller.get_user_group_permissions_using_get(user_group_id.id, **kwargs)

    def load_user_group_permission_infos(self, permissions, **kwargs):
        return self.group_permission_controller.load_user_group_permission_infos_using_post(permissions, **kwargs)

    def save_group_permission(self, group_permission, **kwargs):
        return self.group_permission_controller.save_group_permission_using_post(group_permission, **kwargs)

    """ CustomMenuController endpoints """

    def get_current_custom_menu(self, **kwargs):
        return self.custom_menu_controller.get_current_custom_menu_using_get(**kwargs)

    def get_custom_menu(self, **kwargs):
        return self.custom_menu_controller.get_custom_menu_using_get(**kwargs)

    def save_custom_menu(self, **kwargs):
        return self.custom_menu_controller.save_custom_menu_using_post(**kwargs)

    """ ReportController endpoints """

    def download_dashboard_report(self, dashboard_id: DashboardId, report_params, **kwargs):
        return self.report_controller.download_dashboard_report_using_post(dashboard_id.id, report_params, **kwargs)

    def download_test_report(self, report_config, **kwargs):
        return self.report_controller.download_test_report_using_post(report_config, **kwargs)

    """ RuleEngineController endpoints """

    def handle_rule_engine_request(self, request_body, **kwargs):
        return self.rule_engine_controller.handle_rule_engine_request_using_post(request_body, **kwargs)

    def handle_rule_engine_request1(self, entity_id: EntityId, timeout, request_body, **kwargs):
        return self.rule_engine_controller.handle_rule_engine_request_using_post1(entity_id.entity_type, entity_id.id, timeout, request_body, **kwargs)

    def handle_rule_engine_request2(self, entity_id: EntityId, request_body, **kwargs):
        return self.rule_engine_controller.handle_rule_engine_request_using_post2(entity_id.entity_type, entity_id.id, request_body, **kwargs)

    """ ConverterController endpoints """

    def delete_converter(self, converter_id: ConverterId, **kwargs):
        return self.converter_controller.delete_converter_using_delete(converter_id.id, **kwargs)

    def get_converter_by_id(self, converter_id: ConverterId, **kwargs):
        return self.converter_controller.get_converter_by_id_using_get(converter_id.id, **kwargs)

    def get_converters_by_ids(self, converter_ids, **kwargs):
        return self.converter_controller.get_converters_by_ids_using_get(converter_ids, **kwargs)

    def get_converters(self, page_size=100, page=0, **kwargs):
        return self.converter_controller.get_converters_using_get(str(page_size), str(page), **kwargs)

    def get_latest_converter_debug_input(self, converter_id: ConverterId, **kwargs):
        return self.converter_controller.get_latest_converter_debug_input_using_get(converter_id.id, **kwargs)

    def save_converter(self, converter, **kwargs):
        return self.converter_controller.save_converter_using_post(converter, **kwargs)

    def test_down_link_converter(self, input_params, **kwargs):
        return self.converter_controller.test_down_link_converter_using_post(input_params, **kwargs)

    def test_up_link_converter(self, input_params, **kwargs):
        return self.converter_controller.test_up_link_converter_using_post(input_params, **kwargs)

    """ TrailController endpoints """

    def delete_device1(self, **kwargs):
        return self.trail_controller.delete_device_using_delete1(**kwargs)

    """ ThingParkIntegrationController endpoints """

    def process_request_tpe_using_delete(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_tpe_using_delete(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_tpe_using_get(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_tpe_using_get(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_tpe_using_head(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_tpe_using_head(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_tpe_using_options(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_tpe_using_options(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_tpe_using_patch(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_tpe_using_patch(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_tpe_using_post(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_tpe_using_post(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_tpe_using_put(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_tpe_using_put(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_tpe_using_delete1(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_using_delete3(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_tpe_using_get1(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_using_get3(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_using_head3(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_using_head3(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_using_options3(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_using_options3(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_using_patch3(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_using_patch3(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request9(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_using_post9(routing_key, all_request_params, msg, request_headers, **kwargs)

    def process_request_using_put3(self, routing_key, all_request_params, msg, request_headers, **kwargs):
        return self.thing_park_integration_controller.process_request_using_put3(routing_key, all_request_params, msg, request_headers, **kwargs)

    def get_tenants_by_ids(self, tenant_ids, **kwargs):
        return self.tenant_controller.get_tenants_by_ids_using_get(tenant_ids, **kwargs)

    def export_group_dashboards(self, entity_group_id: EntityGroupId, limit, **kwargs):
        return self.dashboard_controller.export_group_dashboards_using_get(entity_group_id.id, limit, **kwargs)

    def get_dashboards_by_entity_group_id(self, entity_group_id: EntityGroupId, page_size=100, page=0, **kwargs):
        return self.dashboard_controller.get_dashboards_by_entity_group_id_using_get(entity_group_id.id, str(page_size), str(page), **kwargs)

    def get_dashboards_by_ids(self, dashboard_ids, **kwargs):
        return self.dashboard_controller.get_dashboards_by_ids_using_get(dashboard_ids, **kwargs)

    def get_group_dashboards(self, entity_group_id: EntityGroupId, page_size=100, page=0, **kwargs):
        return self.dashboard_controller.get_group_dashboards_using_get(entity_group_id.id, str(page_size), str(page), **kwargs)

    def get_user_dashboards(self, page_size=100, page=0, **kwargs):
        return self.dashboard_controller.get_user_dashboards_using_get(str(page_size), str(page), **kwargs)

    def import_group_dashboards(self, entity_group_id: EntityGroupId, dashboard_list, **kwargs):
        return self.dashboard_controller.import_group_dashboards_using_post(entity_group_id.id, dashboard_list, **kwargs)

    def find_by_from(self, from_id, from_type, **kwargs):
        return self.entity_relation_controller.find_by_from_using_get(from_id, from_type, **kwargs)

    def find_by_from1(self, from_id, from_type, relation_type, **kwargs):
        return self.entity_relation_controller.find_by_from_using_get1(from_id, from_type, relation_type, **kwargs)

    def find_by_to(self, to_id, to_type, **kwargs):
        return self.entity_relation_controller.find_by_to_using_get(to_id, to_type, **kwargs)

    def find_by_to1(self, to_id, to_type, relation_type, **kwargs):
        return self.entity_relation_controller.find_by_to_using_get1(to_id, to_type, relation_type, **kwargs)

    def get_entity_views_by_entity_group_id(self, entity_group_id: EntityGroupId, page_size=100, page=0, **kwargs):
        return self.entity_view_controller.get_entity_views_by_entity_group_id_using_get(entity_group_id.id, str(page_size), str(page), **kwargs)

    def get_entity_views_by_ids(self, entity_view_ids, **kwargs):
        return self.entity_view_controller.get_entity_views_by_ids_using_get(entity_view_ids, **kwargs)

    def get_user_entity_views(self, page_size=100, page=0, **kwargs):
        return self.entity_view_controller.get_user_entity_views_using_get(str(page_size), str(page), **kwargs)

    def get_customers_by_entity_group_id(self, entity_group_id: EntityGroupId, page_size=100, page=0, **kwargs):
        return self.customer_controller.get_customers_by_entity_group_id_using_get(entity_group_id.id, str(page_size), str(page), **kwargs)

    def get_customers_by_ids(self, customer_ids, **kwargs):
        return self.customer_controller.get_customers_by_ids_using_get(customer_ids, **kwargs)

    def get_user_customers(self, page_size=100, page=0, **kwargs):
        return self.customer_controller.get_user_customers_using_get(str(page_size), str(page), **kwargs)

    def __load_controllers(self):
        self.auth_controller = AuthControllerApi(self.api_client)
        self.admin_controller = AdminControllerApi(self.api_client)
        self.alarm_controller = AlarmControllerApi(self.api_client)
        self.asset_controller = AssetControllerApi(self.api_client)
        self.audit_log_controller = AuditLogControllerApi(self.api_client)
        self.blob_entity_controller = BlobEntityControllerApi(self.api_client)
        self.component_descriptor_controller = ComponentDescriptorControllerApi(self.api_client)
        self.converter_controller = ConverterControllerApi(self.api_client)
        self.custom_menu_controller = CustomMenuControllerApi(self.api_client)
        self.custom_translation_controller = CustomTranslationControllerApi(self.api_client)
        self.customer_controller = CustomerControllerApi(self.api_client)
        self.dashboard_controller = DashboardControllerApi(self.api_client)
        self.device_api_controller = DeviceApiControllerApi(self.api_client)
        self.device_controller = DeviceControllerApi(self.api_client)
        self.device_profile_controller = DeviceProfileControllerApi(self.api_client)
        self.entity_group_controller = EntityGroupControllerApi(self.api_client)
        self.entity_query_controller = EntityQueryControllerApi(self.api_client)
        self.entity_relation_controller = EntityRelationControllerApi(self.api_client)
        self.entity_view_controller = EntityViewControllerApi(self.api_client)
        self.event_controller = EventControllerApi(self.api_client)
        self.group_permission_controller = GroupPermissionControllerApi(self.api_client)
        self.http_integration_controller = HttpIntegrationControllerApi(self.api_client)
        self.integration_controller = IntegrationControllerApi(self.api_client)
        self.o_auth_2_config_template_controller = OAuth2ConfigTemplateControllerApi(self.api_client)
        self.o_auth_2_controller = OAuth2ControllerApi(self.api_client)
        self.ocean_connect_integration_controller = OceanConnectIntegrationControllerApi(self.api_client)
        self.owner_controller = OwnerControllerApi(self.api_client)
        self.queue_controller = QueueControllerApi(self.api_client)
        self.report_controller = ReportControllerApi(self.api_client)
        self.role_controller = RoleControllerApi(self.api_client)
        self.rpc_controller = RpcControllerApi(self.api_client)
        self.rule_chain_controller = RuleChainControllerApi(self.api_client)
        self.rule_engine_controller = RuleEngineControllerApi(self.api_client)
        self.scheduler_event_controller = SchedulerEventControllerApi(self.api_client)
        self.self_registration_controller = SelfRegistrationControllerApi(self.api_client)
        self.sigfox_integration_controller = SigFoxIntegrationControllerApi(self.api_client)
        self.sign_up_controller = SignUpControllerApi(self.api_client)
        self.tmobile_iot_cdp_integration_controller = TMobileIotCdpIntegrationControllerApi(self.api_client)
        self.telemetry_controller = TelemetryControllerApi(self.api_client)
        self.tenant_controller = TenantControllerApi(self.api_client)
        self.trail_controller = TrailControllerApi(self.api_client)
        self.tenant_profile_controller = TenantProfileControllerApi(self.api_client)
        self.thing_park_integration_controller = ThingParkIntegrationControllerApi(self.api_client)
        self.user_controller = UserControllerApi(self.api_client)
        self.user_permissions_controller = UserPermissionsControllerApi(self.api_client)
        self.white_labeling_controller = WhiteLabelingControllerApi(self.api_client)
        self.widget_type_controller = WidgetTypeControllerApi(self.api_client)
        self.widgets_bundle_controller = WidgetsBundleControllerApi(self.api_client)

    @staticmethod
    def get_type(type):
        return type.entity_type if hasattr(type, "entity_type") else type

    @staticmethod
    def get_id(id):
        return id.id if hasattr(id, "id") else id



# coding: utf-8

"""
    ThingsBoard REST API

    For instructions how to authorize requests please visit <a href='http://thingsboard.io/docs/reference/rest-api/'>REST API documentation page</a>.  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class OAuth2MapperConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'activate_user': 'bool',
        'allow_user_creation': 'bool',
        'basic': 'OAuth2BasicMapperConfig',
        'custom': 'OAuth2CustomMapperConfig',
        'type': 'str'
    }

    attribute_map = {
        'activate_user': 'activateUser',
        'allow_user_creation': 'allowUserCreation',
        'basic': 'basic',
        'custom': 'custom',
        'type': 'type'
    }

    def __init__(self, activate_user=None, allow_user_creation=None, basic=None, custom=None, type=None):  # noqa: E501
        """OAuth2MapperConfig - a model defined in Swagger"""  # noqa: E501

        self._activate_user = None
        self._allow_user_creation = None
        self._basic = None
        self._custom = None
        self._type = None
        self.discriminator = None

        if activate_user is not None:
            self.activate_user = activate_user
        if allow_user_creation is not None:
            self.allow_user_creation = allow_user_creation
        if basic is not None:
            self.basic = basic
        if custom is not None:
            self.custom = custom
        if type is not None:
            self.type = type

    @property
    def activate_user(self):
        """Gets the activate_user of this OAuth2MapperConfig.  # noqa: E501


        :return: The activate_user of this OAuth2MapperConfig.  # noqa: E501
        :rtype: bool
        """
        return self._activate_user

    @activate_user.setter
    def activate_user(self, activate_user):
        """Sets the activate_user of this OAuth2MapperConfig.


        :param activate_user: The activate_user of this OAuth2MapperConfig.  # noqa: E501
        :type: bool
        """

        self._activate_user = activate_user

    @property
    def allow_user_creation(self):
        """Gets the allow_user_creation of this OAuth2MapperConfig.  # noqa: E501


        :return: The allow_user_creation of this OAuth2MapperConfig.  # noqa: E501
        :rtype: bool
        """
        return self._allow_user_creation

    @allow_user_creation.setter
    def allow_user_creation(self, allow_user_creation):
        """Sets the allow_user_creation of this OAuth2MapperConfig.


        :param allow_user_creation: The allow_user_creation of this OAuth2MapperConfig.  # noqa: E501
        :type: bool
        """

        self._allow_user_creation = allow_user_creation

    @property
    def basic(self):
        """Gets the basic of this OAuth2MapperConfig.  # noqa: E501


        :return: The basic of this OAuth2MapperConfig.  # noqa: E501
        :rtype: OAuth2BasicMapperConfig
        """
        return self._basic

    @basic.setter
    def basic(self, basic):
        """Sets the basic of this OAuth2MapperConfig.


        :param basic: The basic of this OAuth2MapperConfig.  # noqa: E501
        :type: OAuth2BasicMapperConfig
        """

        self._basic = basic

    @property
    def custom(self):
        """Gets the custom of this OAuth2MapperConfig.  # noqa: E501


        :return: The custom of this OAuth2MapperConfig.  # noqa: E501
        :rtype: OAuth2CustomMapperConfig
        """
        return self._custom

    @custom.setter
    def custom(self, custom):
        """Sets the custom of this OAuth2MapperConfig.


        :param custom: The custom of this OAuth2MapperConfig.  # noqa: E501
        :type: OAuth2CustomMapperConfig
        """

        self._custom = custom

    @property
    def type(self):
        """Gets the type of this OAuth2MapperConfig.  # noqa: E501


        :return: The type of this OAuth2MapperConfig.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OAuth2MapperConfig.


        :param type: The type of this OAuth2MapperConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["BASIC", "CUSTOM", "GITHUB"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OAuth2MapperConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OAuth2MapperConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#
#

# flake8: noqa
from __future__ import absolute_import

from tb_rest_client32.api.api_ce.admin_controller_api import AdminControllerApi
from tb_rest_client32.api.api_ce.alarm_controller_api import AlarmControllerApi
from tb_rest_client32.api.api_ce.asset_controller_api import AssetControllerApi
from tb_rest_client32.api.api_ce.audit_log_controller_api import AuditLogControllerApi
from tb_rest_client32.api.api_ce.auth_controller_api import AuthControllerApi
from tb_rest_client32.api.api_ce.component_descriptor_controller_api import ComponentDescriptorControllerApi
from tb_rest_client32.api.api_ce.customer_controller_api import CustomerControllerApi
from tb_rest_client32.api.api_ce.dashboard_controller_api import DashboardControllerApi
from tb_rest_client32.api.api_ce.device_controller_api import DeviceControllerApi
from tb_rest_client32.api.api_ce.device_profile_controller_api import DeviceProfileControllerApi
from tb_rest_client32.api.api_ce.entity_query_controller_api import EntityQueryControllerApi
from tb_rest_client32.api.api_ce.entity_relation_controller_api import EntityRelationControllerApi
from tb_rest_client32.api.api_ce.entity_view_controller_api import EntityViewControllerApi
from tb_rest_client32.api.api_ce.event_controller_api import EventControllerApi
from tb_rest_client32.api.api_ce.o_auth_2_config_template_controller_api import OAuth2ConfigTemplateControllerApi
from tb_rest_client32.api.api_ce.o_auth_2_controller_api import OAuth2ControllerApi
from tb_rest_client32.api.api_ce.queue_controller_api import QueueControllerApi
from tb_rest_client32.api.api_ce.rpc_controller_api import RpcControllerApi
from tb_rest_client32.api.api_ce.rule_chain_controller_api import RuleChainControllerApi
from tb_rest_client32.api.api_ce.telemetry_controller_api import TelemetryControllerApi
from tb_rest_client32.api.api_ce.tenant_controller_api import TenantControllerApi
from tb_rest_client32.api.api_ce.tenant_profile_controller_api import TenantProfileControllerApi
from tb_rest_client32.api.api_ce.user_controller_api import UserControllerApi
from tb_rest_client32.api.api_ce.widget_type_controller_api import WidgetTypeControllerApi
from tb_rest_client32.api.api_ce.widgets_bundle_controller_api import WidgetsBundleControllerApi
from tb_rest_client32.api.api_pe.blob_entity_controller_api import BlobEntityControllerApi
from tb_rest_client32.api.api_pe.converter_controller_api import ConverterControllerApi
from tb_rest_client32.api.api_pe.custom_menu_controller_api import CustomMenuControllerApi
from tb_rest_client32.api.api_pe.custom_translation_controller_api import CustomTranslationControllerApi
from tb_rest_client32.api.api_pe.entity_group_controller_api import EntityGroupControllerApi
from tb_rest_client32.api.api_pe.group_permission_controller_api import GroupPermissionControllerApi
from tb_rest_client32.api.api_pe.http_integration_controller_api import HttpIntegrationControllerApi
from tb_rest_client32.api.api_pe.integration_controller_api import IntegrationControllerApi
from tb_rest_client32.api.api_pe.ocean_connect_integration_controller_api import OceanConnectIntegrationControllerApi
from tb_rest_client32.api.api_pe.owner_controller_api import OwnerControllerApi
from tb_rest_client32.api.api_pe.report_controller_api import ReportControllerApi
from tb_rest_client32.api.api_pe.role_controller_api import RoleControllerApi
from tb_rest_client32.api.api_pe.rule_engine_controller_api import RuleEngineControllerApi
from tb_rest_client32.api.api_pe.scheduler_event_controller_api import SchedulerEventControllerApi
from tb_rest_client32.api.api_pe.self_registration_controller_api import SelfRegistrationControllerApi
from tb_rest_client32.api.api_pe.sig_fox_integration_controller_api import SigFoxIntegrationControllerApi
from tb_rest_client32.api.api_pe.sign_up_controller_api import SignUpControllerApi
from tb_rest_client32.api.api_pe.t_mobile_iot_cdp_integration_controller_api import \
    TMobileIotCdpIntegrationControllerApi
from tb_rest_client32.api.api_pe.thing_park_integration_controller_api import ThingParkIntegrationControllerApi
from tb_rest_client32.api.api_pe.trail_controller_api import TrailControllerApi
from tb_rest_client32.api.api_pe.user_permissions_controller_api import UserPermissionsControllerApi
from tb_rest_client32.api.api_pe.white_labeling_controller_api import WhiteLabelingControllerApi
# import ApiClient
from tb_rest_client32.api_client import ApiClient
from tb_rest_client32.configuration import Configuration



# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#
#

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client32.api_client import ApiClient


class AuditLogControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.    
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_audit_logs_by_customer_id_using_get(self, customer_id, page_size, page, **kwargs):  # noqa: E501
        """getAuditLogsByCustomerId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_customer_id_using_get(customer_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_id: customerId (required)
        :param str page_size: pageSize (required)
        :param str page: page (required)
        :param str text_search: textSearch
        :param str sort_property: sortProperty
        :param str sort_order: sortOrder
        :param int start_time: startTime
        :param int end_time: endTime
        :param str action_types: actionTypes
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_audit_logs_by_customer_id_using_get_with_http_info(customer_id, page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_audit_logs_by_customer_id_using_get_with_http_info(customer_id, page_size, page, **kwargs)  # noqa: E501
            return data

    def get_audit_logs_by_customer_id_using_get_with_http_info(self, customer_id, page_size, page, **kwargs):  # noqa: E501
        """getAuditLogsByCustomerId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_customer_id_using_get_with_http_info(customer_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_id: customerId (required)
        :param str page_size: pageSize (required)
        :param str page: page (required)
        :param str text_search: textSearch
        :param str sort_property: sortProperty
        :param str sort_order: sortOrder
        :param int start_time: startTime
        :param int end_time: endTime
        :param str action_types: actionTypes
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'page_size', 'page', 'text_search', 'sort_property', 'sort_order', 'start_time', 'end_time', 'action_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `get_audit_logs_by_customer_id_using_get`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_audit_logs_by_customer_id_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_audit_logs_by_customer_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501
        if 'action_types' in params:
            query_params.append(('actionTypes', params['action_types']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/audit/logs/customer/{customerId}{?textSearch,sortProperty,sortOrder,startTime,endTime,actionTypes,pageSize,page}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataAuditLog',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_audit_logs_by_entity_id_using_get(self, entity_type, entity_id, page_size, page, **kwargs):  # noqa: E501
        """getAuditLogsByEntityId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_entity_id_using_get(entity_type, entity_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: entityType (required)
        :param str entity_id: entityId (required)
        :param str page_size: pageSize (required)
        :param str page: page (required)
        :param str text_search: textSearch
        :param str sort_property: sortProperty
        :param str sort_order: sortOrder
        :param int start_time: startTime
        :param int end_time: endTime
        :param str action_types: actionTypes
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_audit_logs_by_entity_id_using_get_with_http_info(entity_type, entity_id, page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_audit_logs_by_entity_id_using_get_with_http_info(entity_type, entity_id, page_size, page, **kwargs)  # noqa: E501
            return data

    def get_audit_logs_by_entity_id_using_get_with_http_info(self, entity_type, entity_id, page_size, page, **kwargs):  # noqa: E501
        """getAuditLogsByEntityId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_entity_id_using_get_with_http_info(entity_type, entity_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: entityType (required)
        :param str entity_id: entityId (required)
        :param str page_size: pageSize (required)
        :param str page: page (required)
        :param str text_search: textSearch
        :param str sort_property: sortProperty
        :param str sort_order: sortOrder
        :param int start_time: startTime
        :param int end_time: endTime
        :param str action_types: actionTypes
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['entity_type', 'entity_id', 'page_size', 'page', 'text_search', 'sort_property', 'sort_order', 'start_time', 'end_time', 'action_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'entity_type' is set
        if ('entity_type' not in params or
                params['entity_type'] is None):
            raise ValueError("Missing the required parameter `entity_type` when calling `get_audit_logs_by_entity_id_using_get`")  # noqa: E501
        # verify the required parameter 'entity_id' is set
        if ('entity_id' not in params or
                params['entity_id'] is None):
            raise ValueError("Missing the required parameter `entity_id` when calling `get_audit_logs_by_entity_id_using_get`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_audit_logs_by_entity_id_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_audit_logs_by_entity_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'entity_type' in params:
            path_params['entityType'] = params['entity_type']  # noqa: E501
        if 'entity_id' in params:
            path_params['entityId'] = params['entity_id']  # noqa: E501

        query_params = []
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501
        if 'action_types' in params:
            query_params.append(('actionTypes', params['action_types']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/audit/logs/entity/{entityType}/{entityId}{?textSearch,sortProperty,sortOrder,startTime,endTime,actionTypes,pageSize,page}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataAuditLog',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_audit_logs_by_user_id_using_get(self, user_id, page_size, page, **kwargs):  # noqa: E501
        """getAuditLogsByUserId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_user_id_using_get(user_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: userId (required)
        :param str page_size: pageSize (required)
        :param str page: page (required)
        :param str text_search: textSearch
        :param str sort_property: sortProperty
        :param str sort_order: sortOrder
        :param int start_time: startTime
        :param int end_time: endTime
        :param str action_types: actionTypes
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_audit_logs_by_user_id_using_get_with_http_info(user_id, page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_audit_logs_by_user_id_using_get_with_http_info(user_id, page_size, page, **kwargs)  # noqa: E501
            return data

    def get_audit_logs_by_user_id_using_get_with_http_info(self, user_id, page_size, page, **kwargs):  # noqa: E501
        """getAuditLogsByUserId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_user_id_using_get_with_http_info(user_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: userId (required)
        :param str page_size: pageSize (required)
        :param str page: page (required)
        :param str text_search: textSearch
        :param str sort_property: sortProperty
        :param str sort_order: sortOrder
        :param int start_time: startTime
        :param int end_time: endTime
        :param str action_types: actionTypes
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'page_size', 'page', 'text_search', 'sort_property', 'sort_order', 'start_time', 'end_time', 'action_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_audit_logs_by_user_id_using_get`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_audit_logs_by_user_id_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_audit_logs_by_user_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501
        if 'action_types' in params:
            query_params.append(('actionTypes', params['action_types']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/audit/logs/user/{userId}{?textSearch,sortProperty,sortOrder,startTime,endTime,actionTypes,pageSize,page}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataAuditLog',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_audit_logs_using_get(self, page_size, page, **kwargs):  # noqa: E501
        """getAuditLogs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_using_get(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_size: pageSize (required)
        :param str page: page (required)
        :param str text_search: textSearch
        :param str sort_property: sortProperty
        :param str sort_order: sortOrder
        :param int start_time: startTime
        :param int end_time: endTime
        :param str action_types: actionTypes
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_audit_logs_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_audit_logs_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
            return data

    def get_audit_logs_using_get_with_http_info(self, page_size, page, **kwargs):  # noqa: E501
        """getAuditLogs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_using_get_with_http_info(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_size: pageSize (required)
        :param str page: page (required)
        :param str text_search: textSearch
        :param str sort_property: sortProperty
        :param str sort_order: sortOrder
        :param int start_time: startTime
        :param int end_time: endTime
        :param str action_types: actionTypes
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page', 'text_search', 'sort_property', 'sort_order', 'start_time', 'end_time', 'action_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_audit_logs_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_audit_logs_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501
        if 'action_types' in params:
            query_params.append(('actionTypes', params['action_types']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/audit/logs{?textSearch,sortProperty,sortOrder,startTime,endTime,actionTypes,pageSize,page}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataAuditLog',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#
#

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client32.api_client import ApiClient


class AuthControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def activate_user_using_post(self, activate_request, **kwargs):  # noqa: E501
        """activateUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.activate_user_using_post(activate_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param dict activate_request: activateRequest (required)
        :param bool send_activation_mail: sendActivationMail
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.activate_user_using_post_with_http_info(activate_request, **kwargs)  # noqa: E501
        else:
            (data) = self.activate_user_using_post_with_http_info(activate_request, **kwargs)  # noqa: E501
            return data

    def activate_user_using_post_with_http_info(self, activate_request, **kwargs):  # noqa: E501
        """activateUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.activate_user_using_post_with_http_info(activate_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activate_request: activateRequest (required)
        :param bool send_activation_mail: sendActivationMail
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activate_request', 'send_activation_mail']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):

            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activate_request' is set
        if ('activate_request' not in params or
                params['activate_request'] is None):
            raise ValueError("Missing the required parameter `activate_request` when calling `activate_user_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'send_activation_mail' in params:
            query_params.append(('sendActivationMail', params['send_activation_mail']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'activate_request' in params:
            body_params = params['activate_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/noauth/activate{?sendActivationMail}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_password_using_post(self, change_password_request, **kwargs):  # noqa: E501
        """changePassword  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.change_password_using_post(change_password_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str change_password_request: changePasswordRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_password_using_post_with_http_info(change_password_request, **kwargs)  # noqa: E501
        else:
            (data) = self.change_password_using_post_with_http_info(change_password_request, **kwargs)  # noqa: E501
            return data

    def change_password_using_post_with_http_info(self, change_password_request, **kwargs):  # noqa: E501
        """changePassword  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.change_password_using_post_with_http_info(change_password_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str change_password_request: changePasswordRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['change_password_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):

            params[key] = val
        del params['kwargs']
        # verify the required parameter 'change_password_request' is set
        if ('change_password_request' not in params or
                params['change_password_request'] is None):
            raise ValueError("Missing the required parameter `change_password_request` when calling `change_password_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_password_request' in params:
            body_params = params['change_password_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/auth/changePassword', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def check_activate_token_using_get(self, activate_token, **kwargs):  # noqa: E501
        """checkActivateToken  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.check_activate_token_using_get(activate_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activate_token: activateToken (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.check_activate_token_using_get_with_http_info(activate_token, **kwargs)  # noqa: E501
        else:
            (data) = self.check_activate_token_using_get_with_http_info(activate_token, **kwargs)  # noqa: E501
            return data

    def check_activate_token_using_get_with_http_info(self, activate_token, **kwargs):  # noqa: E501
        """checkActivateToken  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.check_activate_token_using_get_with_http_info(activate_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activate_token: activateToken (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activate_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):

            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activate_token' is set
        if ('activate_token' not in params or
                params['activate_token'] is None):
            raise ValueError("Missing the required parameter `activate_token` when calling `check_activate_token_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'activate_token' in params:
            query_params.append(('activateToken', params['activate_token']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/noauth/activate{?activateToken}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def check_reset_token_using_get(self, reset_token, **kwargs):  # noqa: E501
        """checkResetToken  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.check_reset_token_using_get(reset_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reset_token: resetToken (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.check_reset_token_using_get_with_http_info(reset_token, **kwargs)  # noqa: E501
        else:
            (data) = self.check_reset_token_using_get_with_http_info(reset_token, **kwargs)  # noqa: E501
            return data

    def check_reset_token_using_get_with_http_info(self, reset_token, **kwargs):  # noqa: E501
        """checkResetToken  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.check_reset_token_using_get_with_http_info(reset_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reset_token: resetToken (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reset_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):

            params[key] = val
        del params['kwargs']
        # verify the required parameter 'reset_token' is set
        if ('reset_token' not in params or
                params['reset_token'] is None):
            raise ValueError("Missing the required parameter `reset_token` when calling `check_reset_token_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'reset_token' in params:
            query_params.append(('resetToken', params['reset_token']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/noauth/resetPassword{?resetToken}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_password_policy_using_get(self, **kwargs):  # noqa: E501
        """getUserPasswordPolicy  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.get_user_password_policy_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserPasswordPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_password_policy_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_user_password_policy_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_user_password_policy_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """getUserPasswordPolicy  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.get_user_password_policy_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserPasswordPolicy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):

            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/noauth/userPasswordPolicy', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserPasswordPolicy',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_using_get(self, **kwargs):  # noqa: E501
        """getUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.get_user_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_user_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_user_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """getUser  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.get_user_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):

            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/auth/user', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def logout_using_post(self, **kwargs):  # noqa: E501
        """logout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.logout_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.logout_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.logout_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def logout_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """logout  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.logout_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):

            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/auth/logout', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def request_reset_password_by_email_using_post(self, reset_password_by_email_request, **kwargs):  # noqa: E501
        """requestResetPasswordByEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.request_reset_password_by_email_using_post(reset_password_by_email_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reset_password_by_email_request: resetPasswordByEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.request_reset_password_by_email_using_post_with_http_info(reset_password_by_email_request, **kwargs)  # noqa: E501
        else:
            (data) = self.request_reset_password_by_email_using_post_with_http_info(reset_password_by_email_request, **kwargs)  # noqa: E501
            return data

    def request_reset_password_by_email_using_post_with_http_info(self, reset_password_by_email_request, **kwargs):  # noqa: E501
        """requestResetPasswordByEmail  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.request_reset_password_by_email_using_post_with_http_info(reset_password_by_email_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reset_password_by_email_request: resetPasswordByEmailRequest (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reset_password_by_email_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'reset_password_by_email_request' is set
        if ('reset_password_by_email_request' not in params or
                params['reset_password_by_email_request'] is None):
            raise ValueError("Missing the required parameter `reset_password_by_email_request` when calling `request_reset_password_by_email_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reset_password_by_email_request' in params:
            body_params = params['reset_password_by_email_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/noauth/resetPasswordByEmail', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reset_password_using_post(self, reset_password_request, **kwargs):  # noqa: E501
        """resetPassword  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.reset_password_using_post(reset_password_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reset_password_request: resetPasswordRequest (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reset_password_using_post_with_http_info(reset_password_request, **kwargs)  # noqa: E501
        else:
            (data) = self.reset_password_using_post_with_http_info(reset_password_request, **kwargs)  # noqa: E501
            return data

    def reset_password_using_post_with_http_info(self, reset_password_request, **kwargs):  # noqa: E501
        """resetPassword  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api_pe.reset_password_using_post_with_http_info(reset_password_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str reset_password_request: resetPasswordRequest (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reset_password_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'reset_password_request' is set
        if ('reset_password_request' not in params or
                params['reset_password_request'] is None):
            raise ValueError("Missing the required parameter `reset_password_request` when calling `reset_password_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reset_password_request' in params:
            body_params = params['reset_password_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/noauth/resetPassword', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

    For instructions how to authorize requests please visit <a href='http://thingsboard.io/docs/reference/rest-api/'>REST API documentation page</a>.  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MergedGroupTypePermissionInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'entity_group_ids': 'list[EntityGroupId]',
        'has_generic_read': 'bool'
    }

    attribute_map = {
        'entity_group_ids': 'entityGroupIds',
        'has_generic_read': 'hasGenericRead'
    }

    def __init__(self, entity_group_ids=None, has_generic_read=None):  # noqa: E501
        """MergedGroupTypePermissionInfo - a model defined in Swagger"""  # noqa: E501

        self._entity_group_ids = None
        self._has_generic_read = None
        self.discriminator = None

        if entity_group_ids is not None:
            self.entity_group_ids = entity_group_ids
        if has_generic_read is not None:
            self.has_generic_read = has_generic_read

    @property
    def entity_group_ids(self):
        """Gets the entity_group_ids of this MergedGroupTypePermissionInfo.  # noqa: E501


        :return: The entity_group_ids of this MergedGroupTypePermissionInfo.  # noqa: E501
        :rtype: list[EntityGroupId]
        """
        return self._entity_group_ids

    @entity_group_ids.setter
    def entity_group_ids(self, entity_group_ids):
        """Sets the entity_group_ids of this MergedGroupTypePermissionInfo.


        :param entity_group_ids: The entity_group_ids of this MergedGroupTypePermissionInfo.  # noqa: E501
        :type: list[EntityGroupId]
        """

        self._entity_group_ids = entity_group_ids

    @property
    def has_generic_read(self):
        """Gets the has_generic_read of this MergedGroupTypePermissionInfo.  # noqa: E501


        :return: The has_generic_read of this MergedGroupTypePermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_generic_read

    @has_generic_read.setter
    def has_generic_read(self, has_generic_read):
        """Sets the has_generic_read of this MergedGroupTypePermissionInfo.


        :param has_generic_read: The has_generic_read of this MergedGroupTypePermissionInfo.  # noqa: E501
        :type: bool
        """

        self._has_generic_read = has_generic_read

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MergedGroupTypePermissionInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MergedGroupTypePermissionInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#

import pprint
import re  # noqa: F401

import six


class DashboardInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'assigned_customers': 'list[ShortCustomerInfo]',
        'created_time': 'int',
        'id': 'DashboardId',
        'name': 'str',
        'tenant_id': 'TenantId',
        'title': 'str'
    }

    attribute_map = {
        'assigned_customers': 'assignedCustomers',
        'created_time': 'createdTime',
        'id': 'id',
        'name': 'name',
        'tenant_id': 'tenantId',
        'title': 'title'
    }

    def __init__(self, assigned_customers=None, created_time=None, id=None, name=None, tenant_id=None, title=None):  # noqa: E501
        """DashboardInfo - a model defined in Swagger"""  # noqa: E501

        self._assigned_customers = None
        self._created_time = None
        self._id = None
        self._name = None
        self._tenant_id = None
        self._title = None
        self.discriminator = None

        if assigned_customers is not None:
            self.assigned_customers = assigned_customers
        if created_time is not None:
            self.created_time = created_time
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if title is not None:
            self.title = title

    @property
    def assigned_customers(self):
        """Gets the assigned_customers of this DashboardInfo.  # noqa: E501


        :return: The assigned_customers of this DashboardInfo.  # noqa: E501
        :rtype: list[ShortCustomerInfo]
        """
        return self._assigned_customers

    @assigned_customers.setter
    def assigned_customers(self, assigned_customers):
        """Sets the assigned_customers of this DashboardInfo.


        :param assigned_customers: The assigned_customers of this DashboardInfo.  # noqa: E501
        :type: list[ShortCustomerInfo]
        """

        self._assigned_customers = assigned_customers

    @property
    def created_time(self):
        """Gets the created_time of this DashboardInfo.  # noqa: E501


        :return: The created_time of this DashboardInfo.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this DashboardInfo.


        :param created_time: The created_time of this DashboardInfo.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def id(self):
        """Gets the id of this DashboardInfo.  # noqa: E501


        :return: The id of this DashboardInfo.  # noqa: E501
        :rtype: DashboardId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DashboardInfo.


        :param id: The id of this DashboardInfo.  # noqa: E501
        :type: DashboardId
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DashboardInfo.  # noqa: E501


        :return: The name of this DashboardInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DashboardInfo.


        :param name: The name of this DashboardInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this DashboardInfo.  # noqa: E501


        :return: The tenant_id of this DashboardInfo.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this DashboardInfo.


        :param tenant_id: The tenant_id of this DashboardInfo.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    @property
    def title(self):
        """Gets the title of this DashboardInfo.  # noqa: E501


        :return: The title of this DashboardInfo.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this DashboardInfo.


        :param title: The title of this DashboardInfo.  # noqa: E501
        :type: str
        """

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#

from setuptools import setup, find_packages  # noqa: H301
from os import path

NAME = "tb-rest-client32"
VERSION = "1.2"
REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name=NAME,
    version=VERSION,
    description="ThingsBoard REST API client",
    author_email="info@thingsboard.io",
    license="Apache Software License (Apache Software License 2.0)",
    url="https://thingsboard.io/docs/reference/python-rest-client/",
    keywords=["IoT", "ThingsBoard", "ThingsBoard REST API client"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=long_description,
    download_url='https://github.com/thingsboard/python_tb_rest_client/archive/%s.tar.gz' % VERSION,
    python_requires=">=3.5",
)



# coding: utf-8
#      Copyright 2020. ThingsBoard
#  #
#      Licensed under the Apache License, Version 2.0 (the "License");
#      you may not use this file except in compliance with the License.
#      You may obtain a copy of the License at
#  #
#          http://www.apache.org/licenses/LICENSE-2.0
#  #
#      Unless required by applicable law or agreed to in writing, software
#      distributed under the License is distributed on an "AS IS" BASIS,
#      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#      See the License for the specific language governing permissions and
#      limitations under the License.
#

import pprint
import re  # noqa: F401

import six


class OAuth2BasicMapperConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'always_full_screen': 'bool',
        'customer_name_pattern': 'str',
        'default_dashboard_name': 'str',
        'email_attribute_key': 'str',
        'first_name_attribute_key': 'str',
        'last_name_attribute_key': 'str',
        'tenant_name_pattern': 'str',
        'tenant_name_strategy': 'str'
    }

    attribute_map = {
        'always_full_screen': 'alwaysFullScreen',
        'customer_name_pattern': 'customerNamePattern',
        'default_dashboard_name': 'defaultDashboardName',
        'email_attribute_key': 'emailAttributeKey',
        'first_name_attribute_key': 'firstNameAttributeKey',
        'last_name_attribute_key': 'lastNameAttributeKey',
        'tenant_name_pattern': 'tenantNamePattern',
        'tenant_name_strategy': 'tenantNameStrategy'
    }

    def __init__(self, always_full_screen=None, customer_name_pattern=None, default_dashboard_name=None, email_attribute_key=None, first_name_attribute_key=None, last_name_attribute_key=None, tenant_name_pattern=None, tenant_name_strategy=None):  # noqa: E501
        """OAuth2BasicMapperConfig - a model defined in Swagger"""  # noqa: E501

        self._always_full_screen = None
        self._customer_name_pattern = None
        self._default_dashboard_name = None
        self._email_attribute_key = None
        self._first_name_attribute_key = None
        self._last_name_attribute_key = None
        self._tenant_name_pattern = None
        self._tenant_name_strategy = None
        self.discriminator = None

        if always_full_screen is not None:
            self.always_full_screen = always_full_screen
        if customer_name_pattern is not None:
            self.customer_name_pattern = customer_name_pattern
        if default_dashboard_name is not None:
            self.default_dashboard_name = default_dashboard_name
        if email_attribute_key is not None:
            self.email_attribute_key = email_attribute_key
        if first_name_attribute_key is not None:
            self.first_name_attribute_key = first_name_attribute_key
        if last_name_attribute_key is not None:
            self.last_name_attribute_key = last_name_attribute_key
        if tenant_name_pattern is not None:
            self.tenant_name_pattern = tenant_name_pattern
        if tenant_name_strategy is not None:
            self.tenant_name_strategy = tenant_name_strategy

    @property
    def always_full_screen(self):
        """Gets the always_full_screen of this OAuth2BasicMapperConfig.  # noqa: E501


        :return: The always_full_screen of this OAuth2BasicMapperConfig.  # noqa: E501
        :rtype: bool
        """
        return self._always_full_screen

    @always_full_screen.setter
    def always_full_screen(self, always_full_screen):
        """Sets the always_full_screen of this OAuth2BasicMapperConfig.


        :param always_full_screen: The always_full_screen of this OAuth2BasicMapperConfig.  # noqa: E501
        :type: bool
        """

        self._always_full_screen = always_full_screen

    @property
    def customer_name_pattern(self):
        """Gets the customer_name_pattern of this OAuth2BasicMapperConfig.  # noqa: E501


        :return: The customer_name_pattern of this OAuth2BasicMapperConfig.  # noqa: E501
        :rtype: str
        """
        return self._customer_name_pattern

    @customer_name_pattern.setter
    def customer_name_pattern(self, customer_name_pattern):
        """Sets the customer_name_pattern of this OAuth2BasicMapperConfig.


        :param customer_name_pattern: The customer_name_pattern of this OAuth2BasicMapperConfig.  # noqa: E501
        :type: str
        """

        self._customer_name_pattern = customer_name_pattern

    @property
    def default_dashboard_name(self):
        """Gets the default_dashboard_name of this OAuth2BasicMapperConfig.  # noqa: E501


        :return: The default_dashboard_name of this OAuth2BasicMapperConfig.  # noqa: E501
        :rtype: str
        """
        return self._default_dashboard_name

    @default_dashboard_name.setter
    def default_dashboard_name(self, default_dashboard_name):
        """Sets the default_dashboard_name of this OAuth2BasicMapperConfig.


        :param default_dashboard_name: The default_dashboard_name of this OAuth2BasicMapperConfig.  # noqa: E501
        :type: str
        """

        self._default_dashboard_name = default_dashboard_name

    @property
    def email_attribute_key(self):
        """Gets the email_attribute_key of this OAuth2BasicMapperConfig.  # noqa: E501


        :return: The email_attribute_key of this OAuth2BasicMapperConfig.  # noqa: E501
        :rtype: str
        """
        return self._email_attribute_key

    @email_attribute_key.setter
    def email_attribute_key(self, email_attribute_key):
        """Sets the email_attribute_key of this OAuth2BasicMapperConfig.


        :param email_attribute_key: The email_attribute_key of this OAuth2BasicMapperConfig.  # noqa: E501
        :type: str
        """

        self._email_attribute_key = email_attribute_key

    @property
    def first_name_attribute_key(self):
        """Gets the first_name_attribute_key of this OAuth2BasicMapperConfig.  # noqa: E501


        :return: The first_name_attribute_key of this OAuth2BasicMapperConfig.  # noqa: E501
        :rtype: str
        """
        return self._first_name_attribute_key

    @first_name_attribute_key.setter
    def first_name_attribute_key(self, first_name_attribute_key):
        """Sets the first_name_attribute_key of this OAuth2BasicMapperConfig.


        :param first_name_attribute_key: The first_name_attribute_key of this OAuth2BasicMapperConfig.  # noqa: E501
        :type: str
        """

        self._first_name_attribute_key = first_name_attribute_key

    @property
    def last_name_attribute_key(self):
        """Gets the last_name_attribute_key of this OAuth2BasicMapperConfig.  # noqa: E501


        :return: The last_name_attribute_key of this OAuth2BasicMapperConfig.  # noqa: E501
        :rtype: str
        """
        return self._last_name_attribute_key

    @last_name_attribute_key.setter
    def last_name_attribute_key(self, last_name_attribute_key):
        """Sets the last_name_attribute_key of this OAuth2BasicMapperConfig.


        :param last_name_attribute_key: The last_name_attribute_key of this OAuth2BasicMapperConfig.  # noqa: E501
        :type: str
        """

        self._last_name_attribute_key = last_name_attribute_key

    @property
    def tenant_name_pattern(self):
        """Gets the tenant_name_pattern of this OAuth2BasicMapperConfig.  # noqa: E501


        :return: The tenant_name_pattern of this OAuth2BasicMapperConfig.  # noqa: E501
        :rtype: str
        """
        return self._tenant_name_pattern

    @tenant_name_pattern.setter
    def tenant_name_pattern(self, tenant_name_pattern):
        """Sets the tenant_name_pattern of this OAuth2BasicMapperConfig.


        :param tenant_name_pattern: The tenant_name_pattern of this OAuth2BasicMapperConfig.  # noqa: E501
        :type: str
        """

        self._tenant_name_pattern = tenant_name_pattern

    @property
    def tenant_name_strategy(self):
        """Gets the tenant_name_strategy of this OAuth2BasicMapperConfig.  # noqa: E501


        :return: The tenant_name_strategy of this OAuth2BasicMapperConfig.  # noqa: E501
        :rtype: str
        """
        return self._tenant_name_strategy

    @tenant_name_strategy.setter
    def tenant_name_strategy(self, tenant_name_strategy):
        """Sets the tenant_name_strategy of this OAuth2BasicMapperConfig.


        :param tenant_name_strategy: The tenant_name_strategy of this OAuth2BasicMapperConfig.  # noqa: E501
        :type: str
        """
        allowed_values = ["DOMAIN", "EMAIL", "CUSTOM"]  # noqa: E501
        if tenant_name_strategy not in allowed_values:
            raise ValueError(
                "Invalid value for `tenant_name_strategy` ({0}), must be one of {1}"  # noqa: E501
                .format(tenant_name_strategy, allowed_values)
            )

        self._tenant_name_strategy = tenant_name_strategy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OAuth2BasicMapperConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OAuth2BasicMapperConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
